From 1d91bf400f2448220d0f6d3fbf21fe4e6d420703 Mon Sep 17 00:00:00 2001
From: Akash Mehrotra <mehrotra.akash@gmail.com>
Date: Sat, 13 Aug 2011 11:54:06 +0530
Subject: [PATCH 08/13] LUA: EQ presets getter

---
 modules/lua/libs/equalizer.c          |   21 +++++++++++++++++++--
 share/lua/http/requests/README.txt    |   30 ++++++++++++++++--------------
 share/lua/http/requests/equalizer.xml |    7 +++++++
 3 files changed, 42 insertions(+), 16 deletions(-)

diff --git a/modules/lua/libs/equalizer.c b/modules/lua/libs/equalizer.c
index dfa269b..e8fbf7d 100644
--- a/modules/lua/libs/equalizer.c
+++ b/modules/lua/libs/equalizer.c
@@ -45,6 +45,7 @@
 #include "../libs.h"
 #include "../vlc.h"
 #include "playlist.h"
+#include "../../audio_filter/equalizer_presets.h"
 
 #if !defined WIN32
 # include <locale.h>
@@ -244,14 +245,30 @@ static int vlclua_equalizer_enable ( lua_State *L )
     aout_EnableFilter( p_playlist, "equalizer", state );
     return 0;
 }
-
-
+/*****************************************************************************
+* Get preset names
+*****************************************************************************/
+static int vlclua_equalizer_get_presets( lua_State *L )
+{
+    int i=0;
+    lua_newtable( L );
+    char *str;
+    for ( i=0 ; i < NB_PRESETS ; i++ )
+    {
+        lua_pushstring( L, preset_list_text[i] );
+        asprintf( &str , "id_%d",i );
+        lua_setfield( L , -2 , str );
+        free(str);
+    }
+    return 1;    
+}
 static const luaL_Reg vlclua_equalizer_reg[] = {
     { "preampget", vlclua_preamp_get },
     { "preampset", vlclua_preamp_set },
     { "equalizerget", vlclua_equalizer_get },
     { "equalizerset", vlclua_equalizer_set },
     { "enable", vlclua_equalizer_enable },
+    {"presets",vlclua_equalizer_get_presets },
     { NULL, NULL }
 };
 
diff --git a/share/lua/http/requests/README.txt b/share/lua/http/requests/README.txt
index 4a580a5..e2f99e4 100644
--- a/share/lua/http/requests/README.txt
+++ b/share/lua/http/requests/README.txt
@@ -112,6 +112,22 @@ status.xml or status.json
     +1H:2M -> seek 1 hour and 2 minutes forward
     -10% -> seek 10% back
 
+>command=preamp&val=<val in dB>
+ sets the preamp value, must be >=-20 and <=20
+
+>command=equalizer&band=<band>&val=<gain in dB, must be >=-20 and <=20)
+ set the gain for a specific band
+
+>command=enableeq&val=<0 or 1>
+ 0 --  disables the equalizer
+ 1 --  enables the equalizer
+
+<Displays the equalizer band gains.
+Band 0: 60 Hz, 1: 170 Hz, 2: 310 Hz, 3: 600 Hz, 4: 1 kHz,
+5: 3 kHz, 6: 6 kHz, 7: 12 kHz , 8: 14 kHz , 9: 16 kHz
+
+<Display the list of presets available for the equalizer
+
 playlist.xml:
 =============
 < get the full playlist tree
@@ -131,17 +147,3 @@ vlm_cmd.xml:
   ?command=<cmd>
 > get the error message from <cmd>
 
-equalizer.xml:
-=============
->command=preamp&val=<val in dB>
- sets the preamp value, must be >=-20 and <=20
-
->command=equalizer&band=<band>&val=<gain in dB, must be >=-20 and <=20)
-
->command=enable&val=<0 or 1>
- 0 --  disables the equalizer
- 1 --  enables the equalizer
-
-<Displays the equalizer band gains.
-Band 0: 60 Hz, 1: 170 Hz, 2: 310 Hz, 3: 600 Hz, 4: 1 kHz,
-5: 3 kHz, 6: 6 kHz, 7: 12 kHz , 8: 14 kHz , 9: 16 kHz
diff --git a/share/lua/http/requests/equalizer.xml b/share/lua/http/requests/equalizer.xml
index 62e689c..0071a5d 100644
--- a/share/lua/http/requests/equalizer.xml
+++ b/share/lua/http/requests/equalizer.xml
@@ -26,12 +26,16 @@ vim:syntax=lua
 ]]?>
 <?vlc
 
+require "httprequests"
+
 local command = _GET['command']
 local val = _GET['val']
 local band = _GET['band']
+
 function round(what, precision)
 if what then return math.floor(what*math.pow(10,precision)+0.5) / math.pow(10,precision) else return "" end
 end
+
 if command == "preamp" then vlc.equalizer.preampset(val)
 elseif command == "equalizer" then vlc.equalizer.equalizerset(band,val)
 elseif command == "enable" then
@@ -47,4 +51,7 @@ freq = { 60 , 170 , 310 , 600 , 1000 , 3000 , 6000 , 12000 , 14000 , 16000 }
     <?vlc for i = 0,9
     do print("<band id='"..i.."' freqency = '"..freq[i+1].."'>"..round(vlc.equalizer.equalizerget(i),1).."</band>") end ?>
   </equalizer>
+  <presets>
+    <?vlc httprequests.printTableAsXml(vlc.equalizer.presets(),1) ?>
+  </presets>
 </root>
-- 
1.7.4.1

